﻿using Connected.Services.Modal;
using Microsoft.AspNetCore.Components;
using Microsoft.AspNetCore.Components.Web;

namespace Connected.Components;
public partial class ModalDialog: IDisposable
{
	[Inject] ModalDialogService? ModalService { get; set; }

	protected ElementReference root;
	protected bool IsVisible { get; set; }
	protected string? Title { get; set; }
	protected RenderFragment? Content { get; set; }

	protected bool OverlayClickToClose { get; set; } = true;
	protected Event? OnOk { get; set; }

	protected Event? OnClose { get; set; }

	protected ModalOptions? ModalOptions { get; set; }

	protected override void OnInitialized()
	{
		ModalService.OnShow += ShowModal;
		ModalService.OnClose += CloseModal;
	}


	public void ShowModal(string title, RenderFragment content, Event OnOk = null, Event OnClose = null, ModalOptions options = null, string CancelButtonText = "Cancel", string OKButtonText = "OK")
	{
		Title = title;
		Content = content;
		IsVisible = true;

		this.OKButtonText = OKButtonText;
		this.CancelButtonText = CancelButtonText;

		ModalOptions = options;

		this.OnOk = OnOk;
		this.OnClose = OnClose;

		StateHasChanged();
	}

	public void CloseModal(bool OkClicked = false)
	{
		IsVisible = false;
		Title = "";
		Content = null;
		if (OkClicked)
		{
			if (OnOk is not null)
				OnOk.Delegate.DynamicInvoke(OnOk.args);
		}
		else
		{
			if (OnClose is not null)
				OnClose.Delegate.DynamicInvoke(OnClose.args);
		}

		StateHasChanged();
	}

	public void Dispose()
	{
		if (ModalService is not null)
		{
			ModalService.OnShow -= ShowModal;
			ModalService.OnClose -= CloseModal;
		}
	}

	public string OKButtonText { get; set; } ="OK";

	public string CancelButtonText { get; set; } = "Cancel";

	public void CheckEscape(KeyboardEventArgs args)
	{
		var key = args.Key.ToLower();
		if (key.Equals("escape"))
		{
			CloseModal();
		}
	}

	public void CloseIfEnabled(MouseEventArgs args)
	{
		if (OverlayClickToClose)
		{
			CloseModal();
		}
		OverlayClickToClose = true;
	}

	public void PreventClose(MouseEventArgs args)
	{
		OverlayClickToClose = false;
	}

}